1
0
mirror of https://git.yoctoproject.org/poky synced 2026-05-30 00:20:08 +00:00

apr: Check for libtoolize rather than libtool

Backport a patch from debian to make it check libtoolize rather than libtool.

https://sources.debian.org/data/main/a/apr/1.6.5-1/debian/patches/libtoolize_check.patch

This can also fix:
$ bitbake nativesdk-apr
buildconf: libtool not found.
           You need libtool version 1.4 or newer installed

(From OE-Core rev: 1a1b9e3ff33dea964bdf79bc47b5c7801e4df5a5)

Signed-off-by: Robert Yang <liezhi.yang@windriver.com>
Signed-off-by: Richard Purdie <richard.purdie@linuxfoundation.org>
This commit is contained in:
Robert Yang
2019-09-27 15:25:45 +08:00
committed by Richard Purdie
parent ec1104fd7f
commit 7d751fc737
3 changed files with 31 additions and 34 deletions
@@ -1,32 +0,0 @@
From 4efdc06fb17b8a00a9eca923caa176be741d1e04 Mon Sep 17 00:00:00 2001
From: Hongxu Jia <hongxu.jia@windriver.com>
Date: Thu, 1 Feb 2018 14:56:13 +0800
Subject: [PATCH 1/7] build/buildcheck.sh: improve libtool detection
Support customize libtool by variable assigning, it is helpful
for cross compileing (such as libtool=aarch64-linux-libtool)
Upstream-Status: Submitted [https://github.com/apache/apr/pull/8]
Signed-off-by: Hongxu Jia <hongxu.jia@windriver.com>
---
build/buildcheck.sh | 4 +++-
1 file changed, 3 insertions(+), 1 deletion(-)
diff --git a/build/buildcheck.sh b/build/buildcheck.sh
index ab5df44..f191a41 100755
--- a/build/buildcheck.sh
+++ b/build/buildcheck.sh
@@ -40,7 +40,9 @@ fi
# output is multiline from 1.5 onwards
# Require libtool 1.4 or newer
-libtool=`build/PrintPath glibtool1 glibtool libtool libtool15 libtool14`
+if test -z "$libtool"; then
+ libtool=`build/PrintPath glibtool1 glibtool libtool libtool15 libtool14`
+fi
lt_pversion=`$libtool --version 2>/dev/null|sed -e 's/([^)]*)//g;s/^[^0-9]*//;s/[- ].*//g;q'`
if test -z "$lt_pversion"; then
echo "buildconf: libtool not found."
--
1.8.3.1
@@ -0,0 +1,28 @@
From: Helmut Grohne <helmut@subdivi.de>
Subject: check for libtoolize rather than libtool
Last-Update: 2014-09-19
libtool is now in package libtool-bin, but apr only needs libtoolize.
Upstream-Status: Pending [ from debian: https://sources.debian.org/data/main/a/apr/1.6.5-1/debian/patches/libtoolize_check.patch ]
Signed-off-by: Robert Yang <liezhi.yang@windriver.com>
--- apr.orig/build/buildcheck.sh
+++ apr/build/buildcheck.sh
@@ -39,11 +39,11 @@ fi
# ltmain.sh (GNU libtool 1.1361 2004/01/02 23:10:52) 1.5a
# output is multiline from 1.5 onwards
-# Require libtool 1.4 or newer
-libtool=`build/PrintPath glibtool1 glibtool libtool libtool15 libtool14`
-lt_pversion=`$libtool --version 2>/dev/null|sed -e 's/([^)]*)//g;s/^[^0-9]*//;s/[- ].*//g;q'`
+# Require libtoolize 1.4 or newer
+libtoolize=`build/PrintPath glibtoolize1 glibtoolize libtoolize libtoolize15 libtoolize14`
+lt_pversion=`$libtoolize --version 2>/dev/null|sed -e 's/([^)]*)//g;s/^[^0-9]*//;s/[- ].*//g;q'`
if test -z "$lt_pversion"; then
- echo "buildconf: libtool not found."
+ echo "buildconf: libtoolize not found."
echo " You need libtool version 1.4 or newer installed"
echo " to build APR from SVN."
res=1
+3 -2
View File
@@ -11,13 +11,13 @@ BBCLASSEXTEND = "native nativesdk"
SRC_URI = "${APACHE_MIRROR}/apr/${BPN}-${PV}.tar.bz2 \
file://run-ptest \
file://0001-build-buildcheck.sh-improve-libtool-detection.patch \
file://0002-apr-Remove-workdir-path-references-from-installed-ap.patch \
file://0003-Makefile.in-configure.in-support-cross-compiling.patch \
file://0004-Fix-packet-discards-HTTP-redirect.patch \
file://0005-configure.in-fix-LTFLAGS-to-make-it-work-with-ccache.patch \
file://0006-apr-fix-off_t-size-doesn-t-match-in-glibc-when-cross.patch \
file://0007-explicitly-link-libapr-against-phtread-to-make-gold-.patch \
file://libtoolize_check.patch \
"
SRC_URI[md5sum] = "7a14a83d664e87599ea25ff4432e48a7"
@@ -47,7 +47,8 @@ do_configure_prepend() {
export GREP="grep"
cd ${S}
libtool='${HOST_SYS}-libtool' ./buildconf
# The "2" means libtool version 2.
./buildconf 2
}
FILES_${PN}-dev += "${libdir}/apr.exp ${datadir}/build-1/*"